@@ -1,12 +1,13 @@
 from __future__ import annotations
+
 import asyncio
-from dataclasses import dataclass, field
 import decimal
 import inspect
 import json
 import sys
 import traceback
 import typing as t
+from dataclasses import dataclass, field
 
 try:
     from typing import get_args, get_origin  # type: ignore
@@ -14,12 +15,11 @@ except ImportError:
     # For Python 3.7 support
     from typing_extensions import get_args, get_origin
 
-from docstring_parser import parse, Docstring, DocstringParam  # type: ignore
+from docstring_parser import Docstring, DocstringParam, parse  # type: ignore
 
 from .format import Color, format_text, get_underline
 
-
-__VERSION__ = "0.3.4"
+__VERSION__ = "0.3.5"
 
 
 # If an annotation is one of these values, we will convert the string value
@@ -377,6 +377,15 @@ class CLI:
         cleaned_args = self.get_cleaned_args()
         command: t.Optional[Command] = None
 
+        # Work out if to enable tracebacks
+        try:
+            index = cleaned_args.index("--trace")
+        except ValueError:
+            trace = False
+        else:
+            cleaned_args.pop(index)
+            trace = True
+
         if solo:
             if not self._can_run_in_solo_mode:
                 print(
@@ -416,7 +425,7 @@ class CLI:
                 print(format_text("The command failed.", color=Color.red))
                 print(exception)
 
-                if "--trace" in cleaned_args:
+                if trace:
                     print(traceback.format_exc())
 
                 command.print_help()
